import os
import json

from pyspark.sql import DataFrame
from pyspark.sql import SparkSession
from pyspark.sql.types import StructType
from pyspark.sql.functions import to_binary, col, lit, current_timestamp

import trend_etl.schema.fields as fields

script_dir = os.path.dirname(__file__)


def getspark() -> SparkSession:
    return SparkSession.builder.master("local").appName("local tests").getOrCreate()


def schema_df(*pathcomps):
    with open(os.path.join(script_dir, *pathcomps), "r") as file:
        return StructType.fromJson(json.loads(file.read()))


def get_df(spark, schema: str, *pathcomps) -> DataFrame:
    return spark.read.schema(schema).json(os.path.join(script_dir, *pathcomps))


def get_kafka_df(spark, *pathcomps) -> DataFrame:
    return spark.read.text(os.path.join(script_dir, *pathcomps)).select(
        to_binary(col("value"), lit("utf-8")).alias(fields.kafka_value_field),
        current_timestamp().alias(fields.kafka_timestamp_field),
    )


def get_archive_df(spark, *pathcomps) -> DataFrame:
    return spark.read.text(os.path.join(script_dir, *pathcomps)).select(
        col("value").alias(fields.archive_value_field),
        lit("62e79d1a455bff37d7d29528").alias(fields.archive_job_id_field),
    )
